
# Type: slot_usage


the redefinition of a slot in the context of the containing class definition.

URI: [meta:slot_usage](https://w3id.org/biolink/biolinkml/meta/slot_usage)


## Domain and Range

[ClassDefinition](ClassDefinition.md) ->  <sub>0..*</sub> [SlotDefinition](SlotDefinition.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Many slots may be re-used across different classes, but the meaning of the slot may be refined by context. For example, a generic association model may use slots subject/predicate/object with generic semantics and minimal constraints. When this is subclasses, e.g. to disease-phenotype associations then slot usage may specify both local naming (e.g. subject=disease) and local constraints |

